/**
 * @license
 * Copyright (C) 2016 Dizzy <itsdizzy40@gmail.com>
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file.
 */
"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var TokenError = (function (_super) {
    __extends(TokenError, _super);
    function TokenError(message) {
        var _this = _super.call(this, message) || this;
        _this.name = "TokenError";
        return _this;
    }
    return TokenError;
}(Error));
exports.TokenError = TokenError;
var Token = (function () {
    function Token(token) {
        this.token = token;
    }
    Token.prototype.decodeBase64 = function (str) {
        var output = str.replace(/-/g, '+')
            .replace(/_/g, '/');
        switch (output.length % 4) {
            case 0: {
                break;
            }
            case 2: {
                output += '==';
                break;
            }
            case 3: {
                output += '=';
                break;
            }
            default: {
                throw new TokenError('Illegal base64url string!');
            }
        }
        return decodeURIComponent(escape(typeof window === 'undefined' ? atob(output) : window.atob(output)));
    };
    Token.prototype.decodeToken = function () {
        var parts = this.token.split('.');
        if (parts.length !== 3) {
            throw new TokenError('A JWT Token must have 3 parts!');
        }
        var decoded = this.decodeBase64(parts[1]);
        if (!decoded) {
            throw new TokenError('Cannot decode the token!');
        }
        return JSON.parse(decoded);
    };
    /**
     * Gets the expiration date of this token.
     */
    Token.prototype.getExpirationDate = function () {
        var decoded = this.decodeToken();
        if (!decoded.hasOwnProperty('exp') && !decoded.hasOwnProperty('iat')) {
            return new Date();
        }
        var issueAt = decoded.iat;
        var date = new Date(issueAt * 1000);
        date.setUTCSeconds(decoded.exp);
        return date;
    };
    /**
     * Check whether the token has been expired already.
     */
    Token.prototype.isExpired = function (offsetSeconds) {
        if (offsetSeconds === void 0) { offsetSeconds = 0; }
        var date = this.getExpirationDate();
        if (date.getSeconds() === new Date().getSeconds()) {
            return false;
        }
        return !(date.valueOf() > (new Date().valueOf() + (offsetSeconds * 1000)));
    };
    return Token;
}());
exports.Token = Token;
//# sourceMappingURL=token.model.js.map